@@ -169,6 +169,8 @@ class EsHelper:
             "size": size,
             "from": offset,
         }
+        if sort_list:
+            params["sort"] = sort_list
         try:
             if options.correction_param.get("enable"):
                 mappings = self.pool.es_selector_way(url_func_str=self.pool.format_es_mapping_url,
@@ -182,8 +184,6 @@ class EsHelper:
             params["track_total_hits"] = track_total_hits
         if param_list:
             params["_source"] = {"include": param_list}
-        if sort_list:
-            params["sort"] = sort_list
         start_time = datetime.now()
 
         res = self.pool.es_selector_way(url_func_str=self.pool.format_es_post_url, param_dict={
@@ -197,7 +197,7 @@ class EsHelper:
 
     def correction_param(self, param, mappings):
         for k in param:
-            if k in ["terms", "term", "range", "wildcard"]:
+            if k in ["terms", "term", "range", "wildcard", "sort"]:
                 param[k] = self.correction_field(param[k], mappings, keyword_flag=True)
             elif k in ["match", "match_phrase"]:
                 param[k] = self.correction_field(param[k], mappings)
@@ -209,18 +209,28 @@ class EsHelper:
                         self.correction_param(i, mappings)
 
     def correction_field(self, value, mappings, keyword_flag=False):
-        if value.get("field"):
-            column = value["field"]
-            column = self.check_replace_keyword(column, mappings, keyword_flag)
-            value["field"] = column
-            return value
-        else:
-            column = list(value.keys())[0]
-            data_value = value[column]
-            column = self.check_replace_keyword(column, mappings, keyword_flag)
-            return {
-                column: data_value
-            }
+        if isinstance(value, dict):
+            if value.get("field"):
+                column = value["field"]
+                column = self.check_replace_keyword(column, mappings, keyword_flag)
+                value["field"] = column
+                return value
+            else:
+                column = list(value.keys())[0]
+                data_value = value[column]
+                column = self.check_replace_keyword(column, mappings, keyword_flag)
+                return {
+                    column: data_value
+                }
+        elif isinstance(value, list):
+            for index, i in enumerate(value):
+                column = list(i.keys())[0]
+                data_value = i[column]
+                column = self.check_replace_keyword(column, mappings, keyword_flag)
+                value[index] = {
+                    column: data_value
+                }
+        return value
 
     def check_replace_keyword(self, column, mappings, keyword_flag):
         column = column.replace(".keyword", "")
@@ -312,6 +322,8 @@ class EsHelper:
             }
             , "size": size
         }
+        if sort_list:
+            params["sort"] = sort_list
         try:
             if options.correction_param.get("enable"):
                 mappings = self.pool.es_selector_way(url_func_str=self.pool.format_es_mapping_url,
@@ -323,8 +335,6 @@ class EsHelper:
             logging.error(traceback.format_exc())
         if param_list:
             params["_source"] = {"include": param_list}
-        if sort_list:
-            params["sort"] = sort_list
         res = self.pool.es_selector_way(url_func_str=self.pool.format_scroll_url, param_dict={
             "route_key": route_key,
             "scroll": scroll
